========================
saxton2006
========================

.. {# pkglts, doc

.. image:: https://b326.gitlab.io/saxton2006/_images/badge_doc.svg
    :alt: Documentation status
    :target: https://b326.gitlab.io/saxton2006/

.. image:: https://b326.gitlab.io/saxton2006/_images/badge_pkging_pip.svg
    :alt: PyPI version
    :target: https://pypi.org/project/saxton2006/1.0.1/

.. image:: https://b326.gitlab.io/saxton2006/_images/badge_pkging_conda.svg
    :alt: Conda version
    :target: https://anaconda.org/revesansparole/saxton2006

.. image:: https://badge.fury.io/py/saxton2006.svg
    :alt: PyPI version
    :target: https://badge.fury.io/py/saxton2006

.. #}
.. {# pkglts, glabpkg, after doc

develop: |dvlp_build|_ |dvlp_coverage|_

.. |dvlp_build| image:: https://gitlab.com/b326/saxton2006/badges/develop/pipeline.svg
.. _dvlp_build: https://gitlab.com/b326/saxton2006/commits/develop

.. |dvlp_coverage| image:: https://gitlab.com/b326/saxton2006/badges/develop/coverage.svg
.. _dvlp_coverage: https://gitlab.com/b326/saxton2006/commits/develop


master: |master_build|_ |master_coverage|_

.. |master_build| image:: https://gitlab.com/b326/saxton2006/badges/master/pipeline.svg
.. _master_build: https://gitlab.com/b326/saxton2006/commits/master

.. |master_coverage| image:: https://gitlab.com/b326/saxton2006/badges/master/coverage.svg
.. _master_coverage: https://gitlab.com/b326/saxton2006/commits/master
.. #}

Formalisms published in Saxton and Rawls (2006)

